#! /bin/bash
# A modification of Dean Clatworthy's deploy script as found here: https://github.com/deanc/wordpress-plugin-git-svn
# The difference is that this script lives in the plugin's git repo & doesn't require an existing SVN repo.

# main config
PLUGINSLUG="wow-armory-character"
CURRENTDIR=`pwd`
MAINFILE="wow-armory-character.php" # this should be the name of your main php file in the wordpress plugin

# git config
GITPATH="$CURRENTDIR/" # this file should be in the base of your git repository

# wordpress i18n tools config
TEXTDOMAIN="wow_armory_character"

# svn config
SVNPATH="/tmp/$PLUGINSLUG" # path to a temp SVN repo. No trailing slash required and don't add trunk.
SVNURL="http://plugins.svn.wordpress.org/wow-armory-character" # Remote SVN repo on wordpress.org, with no trailing slash
SVNUSER="blueajcooper" # your svn username


# Let's begin...
echo ".........................................."
echo 
echo "Preparing to deploy wordpress plugin"
echo 
echo ".........................................."
echo 

if [ -n "$(git status --porcelain)" ]; then echo "There are changes to be commited. Exiting...."; exit 1; fi

# Check version in readme.txt is the same as plugin file
NEWVERSION1=`grep "^Stable tag" $GITPATH/readme.txt | awk '{print $NF}'`
echo "readme version: $NEWVERSION1"
NEWVERSION2=`grep "^Version" $GITPATH/$MAINFILE | awk '{print $NF}'`
echo "$MAINFILE version: $NEWVERSION2"

if [ "$NEWVERSION1" != "$NEWVERSION2" ]; then echo "Versions don't match. Exiting...."; exit 1; fi

echo "Versions match in readme.txt and PHP file. Let's proceed..."

echo "Generating translation POT file and commiting it to git"
grunt makepot
git add languages/$TEXTDOMAIN.pot
git commit -m "Deploy.sh auto-generated wow_armory_character.pot translation file"

cd $GITPATH
echo -e "Enter an SVN commit message for this new version: \c"
read COMMITMSG

echo "Tagging new version in git"
git tag -a "$NEWVERSION1" -m "Tagging version $NEWVERSION1 for release"

echo "Pushing latest commit to origin, with tags"
git push origin master
git push origin master --tags

echo 
echo "Creating local copy of SVN repo ..."
svn co $SVNURL $SVNPATH

echo "Exporting the HEAD of master from git to the trunk of SVN"
git checkout-index -a -f --prefix=$SVNPATH/trunk/

echo "Copying assets to correct location"
find assets -type f \( -iname '*.png' -o -iname '*.jpg' \) -exec cp {} $SVNPATH/assets/ \;

echo "Changing directory to SVN and committing assets"
cd $SVNPATH/assets/
# Add all new files that are not set to be ignored
svn status | grep -v "^.[ \t]*\..*" | grep "^?" | awk '{print $2}' | xargs svn add
svn commit --username=$SVNUSER -m "Deploy.sh commit to plugin assets"

echo "Ignoring github specific files and deployment script"
svn propset svn:ignore ".git
.gitignore
.travis.yml
Gruntfile.js
phpunit.xml
package.json
composer.json
composer.lock
bin
tests
assets" "$SVNPATH/trunk/"

echo "Changing directory to SVN and committing to trunk"
cd $SVNPATH/trunk/
# Add all new files that are not set to be ignored
svn status | grep -v "^.[ \t]*\..*" | grep "^?" | awk '{print $2}' | xargs svn add
svn commit --username=$SVNUSER -m "$COMMITMSG"

echo "Creating new SVN tag & committing it"
cd $SVNPATH
svn copy trunk/ tags/$NEWVERSION1/
cd $SVNPATH/tags/$NEWVERSION1
svn commit --username=$SVNUSER -m "Tagging version $NEWVERSION1 for release"

echo "Removing temporary directory $SVNPATH"
rm -fr $SVNPATH/

echo "*** FIN ***"
